-- RZ_DM_QUANTILE ZB_DM_单位时间内访问时间排序


-- 视图
-- step1：
-- 排序
CREATE TEMPORARY VIEW VIEW_RZ_DM_QUANTILE AS 
SELECT
    d1.`applicationname`                                                 as `applicationname`
    ,d1.`agentid`                                                        as `agentid`        
    ,concat(LongTimeToStringUDF(s1.endTime,'yyyy-MM-dd HH:mm'),":00" )   as `time`            
    ,d1.`elapsed`                                                        as `elapsed`
    ,ROW_NUMBER() OVER(PARTITION BY 
                                d1.`applicationname`
                                ,d1.`agentid`
                                ,concat(LongTimeToStringUDF(s1.endTime,'yyyy-MM-dd HH:mm'),":00" )  
                                ORDER BY d1.`elapsed` ASC
                )                                                      AS rownum 
from RZ_ODS.RZ_ODS_KAFKA_RZ.RZDATA d1
where 
    LongTimeToStringUDF(s1.endTime,'yyyy-MM-dd HH:mm:ss') > DATEFORMAT(TIMESTAMPADD(HOUR,-1,LOCALTIMESTAMP),'yyyy-MM-dd HH:mm:ss')

;



-- RZ_DM_QUANTILE_AGENTID ZB_DM_单位时间内访问时间排序按应用统计

insert into RZ_DM_QUANTILE_AGENTID
SELECT
    s1.`applicationname`    as `applicationname`
    ,s1.`agentid`           as `agentid`        
    ,s1.`time`              as `time`           
    ,s1.`quantile50`        as `quantile50`     
    ,s1.`quantile75`        as `quantile75`     
    ,s1.`quantile95`        as `quantile95`     
    ,s1.`quantile99`        as `quantile99`     
    ,DateTimeToLongUDF()        as `createtime`     

from(

    select 
        c1.`applicationname` as   `applicationname`                
        ,c1.`agentid`         as   `agentid`                        
        ,c1.`time`            as   `time`               
        ,v1.`elapsed`         as   `quantile50`             
        ,v2.`elapsed`         as   `quantile75`             
        ,v3.`elapsed`         as   `quantile95`             
        ,v4.`elapsed`         as   `quantile99`                      
    from (
        select 
            d1.`applicationname`                                                    as `applicationname`
            ,d1.`agentid`                                                           as `agentid`        
            ,concat(LongTimeToStringUDF(s1.endTime,'yyyy-MM-dd HH:mm'),":00" )      as `time`   
            ,CEIL(count(1)*0.5   )                                                  as `num50`
            ,CEIL(count(1)*0.75  )                                                  as `num75`
            ,CEIL(count(1)*0.95  )                                                  as `num95`
            ,CEIL(count(1)*0.99  )                                                  as `num99`
        from RZ_ODS.RZ_ODS_KAFKA_RZ.RZDATA d1
        where 
            LongTimeToStringUDF(s1.endTime,'yyyy-MM-dd HH:mm:ss') > DATEFORMAT(TIMESTAMPADD(HOUR,-1,LOCALTIMESTAMP),'yyyy-MM-dd HH:mm:ss')
        group by 
             d1.`applicationname`                                                as `applicationname`
            ,d1.`agentid`                                                        as `agentid`        
            ,concat(LongTimeToStringUDF(s1.endTime,'yyyy-MM-dd HH:mm'),":00" )   as `time`                                                                         
    ) c1
    left join VIEW_RZ_DM_QUANTILE v1 
            on c1.`applicationname` = c2.`applicationname` 
            and c1.`agentid`=c2.`agentid` 
            and c1.`time`  = c2.`time` 
            and c1.`num50` = c2.rownum 
    left join VIEW_RZ_DM_QUANTILE v2 
            on c1.`applicationname` = c2.`applicationname` 
            and c1.`agentid`=c2.`agentid` 
            and c1.`time`  = c2.`time` 
            and c1.`num75` = c2.rownum     
    left join VIEW_RZ_DM_QUANTILE v3 
            on c1.`applicationname` = c2.`applicationname` 
            and c1.`agentid`=c2.`agentid` 
            and c1.`time`  = c2.`time` 
            and c1.`num95` = c2.rownum 
    left join VIEW_RZ_DM_QUANTILE v4 
            on c1.`applicationname` = c2.`applicationname` 
            and c1.`agentid`=c2.`agentid` 
            and c1.`time`  = c2.`time` 
            and c1.`num99` = c2.rownum 
) s1
;







